#version 150

#moj_import <purple_border_gui/util_functions.glsl>

uniform sampler2D Sampler0;

uniform vec4 ColorModulator;

in vec2 texCoord0;
in vec3 cornerTex1;
in vec3 cornerTex2;
in vec3 cornerTex3;

out vec4 fragColor;

void main() {
    vec2 texSize = textureSize(Sampler0, 0);
    vec2 bottomLeftTextureUV = vec2(0, (texSize.y - 1) / texSize.y);
    vec4 bottomLeftPixel = texture(Sampler0, bottomLeftTextureUV);

    vec2 uv = texCoord0;

    if( roughlyEquals( bottomLeftPixel, vec4(0.00392, 0.43529, 0.87059, 0.870588) ) ) {
        // is horse.png
        
        vec2 cornerUV1 = cornerTex1.xy / cornerTex1.z;
        vec2 cornerUV2 = cornerTex2.xy / cornerTex2.z;
        vec2 cornerUV3 = cornerTex3.xy / cornerTex3.z;
        vec2 minUV = min(cornerUV1, min(cornerUV2, cornerUV3));
        vec2 maxUV = max(cornerUV1, max(cornerUV2, cornerUV3));

        // get bottom left uv of quad
        vec2 bottomLeftVertUV = vec2(minUV.x,maxUV.y);
        // subtract 18 to find marker pixel (.5 because inaccuracies)
        bottomLeftVertUV.y += 18.5 / texSize.y;
        vec4 bottomLeftVertPixel = texture(Sampler0, bottomLeftVertUV);

        if(roughlyEquals(bottomLeftVertPixel, vec4(0.00784, 0.43529, 0.87059, 0.870588) ) ) {
            // is llama/donkey chest slots
            float quadWidth = ( maxUV.x - minUV.x ) / 0.35294;
            int quadWidthInSlots = int(ceil(quadWidth * 5));
            vec2 uvInPixels = uv * texSize;

            // adjust uvs to unique textures for slots
                 if ( quadWidthInSlots == 5 ) uvInPixels.x += 90; // 5 slots
            else if ( quadWidthInSlots == 4 ) uvInPixels.x += 180; // 4 slots
            else if ( quadWidthInSlots == 3 ) {uvInPixels.x += 180; uvInPixels.y -= 71; } // 3 slots
            else if ( quadWidthInSlots == 2 ) {uvInPixels.x += 198; uvInPixels.y -= 132; } // 2 slots
            else if ( quadWidthInSlots == 1 ) {uvInPixels.x += 180; uvInPixels.y -= 132; } // 1 slots
        
            uv = uvInPixels / texSize;
        }
    }

    vec4 color = texture(Sampler0, uv);
    if (color.a == 0.0) {
        discard;
    }
    
    fragColor = color * ColorModulator;
}
