#version 150

#moj_import <purple_border_gui/util_functions.glsl>
#moj_import <purple_border_gui/item_selection_bitmap.glsl>

in vec4 vertexColor;
in vec4 gradientColor;
// resolution of gradient or bitmap depending on bgRenderMode
// r = vertical resolution
// g = horizontal resolution
in vec4 gradientResolution;
// 1 = crafting table text box
// 2 = slot highlight
// 3 = red slot highlight
in float renderSlotHighlight;
in vec3 cornerPos1;
in vec3 cornerPos2;
in vec3 cornerPos3;
in vec3 pos;

uniform vec4 ColorModulator;
uniform mat4 ProjMat;

out vec4 fragColor;

void main() {
    vec4 color = vertexColor;

    vec4 gradientColor2 = getGradientWithResolution(gradientColor, gradientResolution);

    vec2 cornerPx1 = cornerPos1.xy / cornerPos1.z;
    vec2 cornerPx2 = cornerPos2.xy / cornerPos2.z;
    vec2 cornerPx3 = cornerPos3.xy / cornerPos3.z;
    vec2 minPos = min(cornerPx1, min(cornerPx2, cornerPx3));
    vec2 maxPos = max(cornerPx1, max(cornerPx2, cornerPx3));

    float quadHeight = int( round( abs( (minPos.y - maxPos.y) ) ) );
    float quadWidth = int( round( abs( (minPos.x - maxPos.x) ) ) );

    // crafting table textbox background
    if(pos.z == 100 && ProjMat[3][0] == -1){
        // tex box background
        if( roughlyEquals( vertexColor, vec4(0,0,0,1) ) && quadHeight == 12 ) {
            discard;
        }
        // text box border 
        else if( ( roughlyEquals( vertexColor, vec4(0.62745, 0.62745, 0.62745, 1) ) || roughlyEquals( vertexColor, vec4(1, 1, 1, 1) ) ) && quadHeight == 14 ) {
            discard;
        }
    }
    else if (pos.z == 0 && ProjMat[3][0] == -1) {

        // tex box background
        if( 
            roughlyEquals( vertexColor, vec4(0,0,0,1) ) && 
            (quadHeight == 20 || quadHeight == 16)
        ) {
            float gradientAmount = getGradientWithResolution(gradientColor, vec4(20,0,0,0)).x;

            vec3 background = vec3(0.6, 0.31765, 0.08235);
            vec3 gradient = background;
            
            // top gradient
            if(gradientAmount > 0.6){
                float gA = (gradientAmount - 0.6) * 4;
                gradient = mix(background, vec3(0.03137, 0.00784, 0.03137), gA);
                gradient = mix(background, vec3(0.50196, 0.25882, 0.05882), gA);
            }
            
            color.rgb = gradient;
        }

        // text box border
        else if( 
            ( roughlyEquals( vertexColor, vec4(0.501961, 0.501961, 0.501961, 1) ) || roughlyEquals( vertexColor, vec4(0.62745, 0.62745, 0.62745,1) ) || roughlyEquals( vertexColor, vec4(1) ) ) && 
            (quadHeight == 22 || quadHeight == 18)
        ) {
            vec4 gradientAmount = getGradientWithResolution(gradientColor, vec4(quadHeight / 4.2, quadWidth / 6, 0, 0)).yxzw;

            vec3 background = vec3(0.9412, 0.7216, 0.2941);
            vec3 lightAccent = vec3(0.9804, 0.9608, 0.8824);
            vec3 darkAccent = vec3(0.7216, 0.3882, 0.102);
            vec3 gradient = background;

            if(gradientAmount.y == 0 && gradientAmount.x != 0 && gradientAmount.x <= 0.9569){
                // bottom row
                gradient = mix(background, darkAccent, clamp( (gradientAmount.x * 2 ) - 0.5, 0, 1 ) );
            }else if(gradientAmount.y >= 0.93 && gradientAmount.x != 0 && gradientAmount.x <= 0.9569){
                // top row
                gradient = mix(lightAccent, background, clamp( (gradientAmount.x * 2 ), 0, 1 ) );
            }else if(gradientAmount.x == 0){
                // right column
                gradient = mix(background, lightAccent, gradientAmount.y);
            }else if(gradientAmount.x >= 0.94) {
                //left column
                gradient = mix(darkAccent, background, gradientAmount.y);
            }
            
            gradient.rgb += vertexColor.rgb - vec3(0.62745, 0.62745, 0.62745);

            color.rgb = gradient.rgb;
        }

        // selected world/server background
        else if( 
            (quadWidth == 268 || quadWidth == 303 || quadWidth == 298) && 
            quadHeight == 34 && 
            roughlyEquals( vertexColor, vec4(0,0,0,1) ) 
        ) {
            vec4 gradientAmount = getGradientWithResolution(gradientColor, vec4(quadHeight, quadWidth, 0, 0)).yxzw;

            vec3 background = vec3(0.1922, 0.0667, 0.1882);
            vec3 lightAccent = vec3(0.4588, 0.1686, 0.4431);

            color.rgb = mix(lightAccent, background, clamp(gradientAmount.y * 7.5, 0, 1) );
        }
        // selected world/server border
        else if( 
            (quadWidth == 270 || quadWidth == 305 || quadWidth == 300) && 
            quadHeight == 36 && 
            (roughlyEquals( vertexColor, vec4(1) ) || roughlyEquals( vertexColor, vec4(0.50196, 0.50196, 0.50196,1) ) )
        ) {
            color.rgb = vec3(0.7412, 0.2824, 0.7176);
        }

        // incompatible resourcepack
        else if (
            quadWidth == 192 &&
            quadHeight == 34 &&
            roughlyEquals(vertexColor, vec4(0.4667, 0, 0, 1))
        ) {
            color.rgb = vec3(0.2157, 0.0706, 0.1137);
        }

        // scrollbar handle
        else if(
            ((quadWidth == 5 || quadWidth >= 481)  ||
             (quadHeight <= 150 && quadWidth >= 150)) &&
            roughlyEquals( vertexColor, vec4(0.7529, 0.7529, 0.7529, 1) )
        ) {
            color.rgb = vec3(0.87059, 0.60784, 0.21569);
        }
        // scrollbar handle shadow
        else if(
            quadWidth == 6 &&
            roughlyEquals( vertexColor, vec4(0.50196, 0.50196, 0.50196, 1) )
        ) {
            color.rgb = vec3(0.6, 0.31765, 0.08235);
        }
        // scrollbar track
        else if(
            quadWidth == 6 &&
            roughlyEquals( vertexColor, vec4(0, 0, 0, 1) )
        ) {
            vec4 gradientAmount = getGradientWithResolution(gradientColor, vec4( quadHeight, quadWidth, 0, 0)).yxzw;

            vec3 background = vec3(0.07843, 0.02353, 0.07843);
            if( gradientAmount.x >= 0.83 || gradientAmount.x == 0 ){
                background = vec3(0.12941, 0.04314, 0.12549);
            }
            vec3 endCapFadeColor = vec3(0.07451, 0.02353, 0.07451);
            vec3 gradient = background;
            
            gradientAmount.y -= gradientAmount.y * gradientAmount.y;
            if(gradientAmount.y < 0.1) {
                gradient = mix(endCapFadeColor, background, (gradientAmount.y * 10));
            }

            color.rgb = gradient;
        }

    }

    // advancement hover background
    if(
        quadWidth == 234 && 
        quadHeight == 113 && 
        vertexColor.a <= 0.29804 && 
        roughlyEquals(vertexColor.rgb, vec3(0,0,0))
    ) {
        color.rgb = vec3(0.07843, 0.02353, 0.07843);
        color.a = vertexColor.a * 2;
    }

    // slot highlight
    if(renderSlotHighlight > 0){
        vec4 gradientColorUV = getGradientWithResolution(gradientColor, gradientResolution) * gradientResolution; // coordinates for bitmap texture
        int x = int(gradientColorUV.g);
        int y = int(gradientColorUV.r);

        for(int i = 0; i < y; i++){
            x += int(gradientResolution.x);
        }

        if(renderSlotHighlight > 2.9){
            color = slotRightClickDraggingColors[slotRightClickDraggingBitmap[x]];
        }else{
            color = slotHighlightColors[slotHighlightBitmap[x]];
        }

    }

    if (color.a == 0.0) {
        discard;
    }

    fragColor = color * ColorModulator;
    // fragColor = vec4(vertexColor.aaa, 1);
    // fragColor = vec4(  quadWidth / 640 , quadHeight / 480 ,0,1);
}
