#version 150

#moj_import <purple_border_gui/util_functions.glsl>
#moj_import <purple_border_gui/item_selection_bitmap.glsl>

in vec3 Position;
in vec4 Color;

uniform mat4 ModelViewMat;
uniform mat4 ProjMat;

out vec4 vertexColor;
out vec4 gradientColor;
out vec4 gradientResolution;
out float renderSlotHighlight;
out vec3 cornerPos1;
out vec3 cornerPos2;
out vec3 cornerPos3;
out vec3 pos;

void main() {
    pos = Position;
    renderSlotHighlight = 0;
    int id = gl_VertexID % 4;
    
    cornerPos1 = cornerPos2 = cornerPos3 = vec3(0);
    switch (id) {
        case 0: cornerPos1 = vec3(pos.xy,1); break;
        case 1: cornerPos2 = vec3(pos.xy,1); break;
        case 2: cornerPos3 = vec3(pos.xy,1); break;
    }

    vertexColor = Color;

    gradientColor = vec4(0);
    gradientResolution = vec4(0);
    if(id == 1 || id == 2) { gradientColor.r = 1; } else { gradientColor.r = 0; } // vertical
    if(id == 2 || id == 3) { gradientColor.g = 1; } else { gradientColor.g = 0; } // horizontal

    if(Position.z == 0 && ProjMat[3][0] == -1){
        // red loading screen
        if( roughlyEquals( Color.rgb, vec3(0.93725, 0.19608, 0.23922) ) ) {
            vertexColor.rgb = vec3(0.07843, 0.02353, 0.07843);
        }
    }

    // slot highlight
    if( roughlyEquals( Color, vec4(1, 1, 1, 0.50196) ) && Position.z == 0 ) {
        float expandSize = (BITMAP_SIZE - 16) / 2;
        float resolution = BITMAP_SIZE;

        // expand quad size
        if(id == 1 || id == 2) { pos.y += expandSize; } else { pos.y -= expandSize; } // vertical
        if(id == 2 || id == 3) { pos.x += expandSize; } else { pos.x -= expandSize; } // horizontal
        // gradient
        if(id == 1 || id == 2) { gradientColor.r = 1; } else { gradientColor.r = 0; } // vertical
        if(id == 2 || id == 3) { gradientColor.g = 1; } else { gradientColor.g = 0; } // horizontal

        renderSlotHighlight = 2;

        gradientResolution.xy = vec2(resolution);
        
        vertexColor = vec4(0.9882, 0.8314, 0.3961, 0.26);
    }
    // bundle highlight
    else if( roughlyEquals( Color, vec4(1, 1, 1, 0.50196) )  && Position.z == 400 ) {
        float expandSize = (BITMAP_SIZE - 16) / 2;
        float resolution = BITMAP_SIZE;

        // expand quad size
        if(id == 1 || id == 2) { pos.y += expandSize; } else { pos.y -= expandSize; } // vertical
        if(id == 2 || id == 3) { pos.x += expandSize; } else { pos.x -= expandSize; } // horizontal
        // gradient
        if(id == 1 || id == 2) { gradientColor.r = 1; } else { gradientColor.r = 0; } // vertical
        if(id == 2 || id == 3) { gradientColor.g = 1; } else { gradientColor.g = 0; } // horizontal

        renderSlotHighlight = 2;

        gradientResolution.xy = vec2(resolution);
        
        vertexColor = vec4(0.9882, 0.8314, 0.3961, 0.26);
    }
    
    gl_Position = ProjMat * ModelViewMat * vec4(pos, 1.0);
}
